summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/notewidgetcontroller.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/notewidgetcontroller.h')
-rw-r--r--umbrello/umbrello/notewidgetcontroller.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/umbrello/umbrello/notewidgetcontroller.h b/umbrello/umbrello/notewidgetcontroller.h
index f3295ce7..081556ed 100644
--- a/umbrello/umbrello/notewidgetcontroller.h
+++ b/umbrello/umbrello/notewidgetcontroller.h
@@ -46,18 +46,18 @@ public:
* Handles a mouse move event.
* Executes base code and then sets the geometry of the editor.
*
* @param me The QMouseEvent event.
*/
- virtual void mouseMoveEvent(QMouseEvent* me);
+ virtual void mouseMoveEvent(TQMouseEvent* me);
/**
* Overriden from UMLWidgetController.
* Handles a mouse release event.
* Executes base code and then draws the text in the note.
*
* @param me The QMouseEvent event.
*/
- virtual void mouseReleaseEvent(QMouseEvent * me);
+ virtual void mouseReleaseEvent(TQMouseEvent * me);
protected:
@@ -66,9 +66,9 @@ protected:
* Executes the action for double click in the widget.
* Shows the dialog to change the text of the note.
*
* @param me The QMouseEvent which triggered the double click event.
*/
- virtual void doMouseDoubleClick(QMouseEvent *me);
+ virtual void doMouseDoubleClick(TQMouseEvent *me);
private:
@@ -46,18 +46,18 @@ public:
* Executes base code and then sets the geometry of the editor.
*
- * @param me The QMouseEvent event.
+ * @param me The TQMouseEvent event.
*/
@@ -46,18 +46,18 @@ public:
* Executes base code and then draws the text in the note.
*
- * @param me The QMouseEvent event.
+ * @param me The TQMouseEvent event.
*/
@@ -66,9 +66,9 @@ protected:
* Shows the dialog to change the text of the note.
*
- * @param me The QMouseEvent which triggered the double click event.
+ * @param me The TQMouseEvent which triggered the double click event.
*/